@@ -5,7 +5,7 @@
 
 /***********************************************************************
  *  This file is part of SpaceChart.
- *  Copyright (C) 1999 Miguel Coca <e970095@zipi.fi.upm.es>
+ *  Copyright (C) 1999 Free Software Foundation, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -26,10 +26,14 @@
 #define _INCLUDE_GUI_H_
 
 #include "starmap.h"
+#include "settings.h"
+#include "star_catalog.h"
 
 typedef struct st_gui gui_t;
 
-gui_t* gui_new( void );
+gui_t* gui_new( settings_t *settings );
+settings_t* gui_get_settings( gui_t *gui );
+star_catalog_t* gui_get_catalog( gui_t *gui );
 void gui_destroy( gui_t *gui );
 
 #endif
