@@ -5,7 +5,7 @@
 
 /***********************************************************************
  *  This file is part of SpaceChart.
- *  Copyright (C) 2000 Miguel Coca <e970095@zipi.fi.upm.es>
+ *  Copyright (C) 2000 Free Software Foundation, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -500,7 +500,9 @@ void cb_select_row( GtkWidget *widget, gint row, gint column,
                     GdkEventButton *event, link_config_t *config )
 {
         config->current_row = row;
-        gtk_widget_set_sensitive( config->del_button, TRUE );
+        gtk_widget_set_sensitive( config->del_button,
+                                  !((struct st_list_data*)
+                                    gtk_clist_get_row_data(GTK_CLIST(config->list), row))->is_default );
         gtk_widget_set_sensitive( config->edit_button, TRUE );
 }
 
