@@ -1,11 +1,12 @@
 /***********************************************************************
  * seldial.c : Implementation of the dialog for establishing a selection 
  *             of stars.
+ * $Id: star_selection_dialog.c,v 1.4 2002/06/09 13:13:49 mcoca Exp $
  ***********************************************************************/
 
 /***********************************************************************
  *  This file is part of SpaceChart.
- *  Copyright (C) 2000 Miguel Coca <e970095@zipi.fi.upm.es>
+ *  Copyright (C) 2000, 2001, 2002 Free Software Foundation, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -32,6 +33,7 @@ struct st_sel_dial
         GtkWidget *dialog;
         GtkWidget *use_min_lum;
         GtkWidget *use_max_lum;
+        GtkWidget *min_lum, *max_lum;
         GtkObject *min_lum_adj;
         GtkObject *max_lum_adj;
         GtkWidget *show_label;
@@ -52,6 +54,8 @@ struct st_sel_dial
 /* Definition of local functions */
 
 static void cb_clicked(GnomeDialog *d, int but, selection_dialog_t* sel_dial);
+static void cb_lum_button_clicked( GtkToggleButton *togglebutton,
+                                   selection_dialog_t* sel_dial);
 static void set_selection( selection_dialog_t* dialog );
 static void get_selection( selection_dialog_t* dialog );
 
@@ -62,7 +66,7 @@ selection_dialog_t* selection_dialog_new( star_selection_t* selection,
                                           void* data )
 {        
         selection_dialog_t* sel_dial;
-        GtkWidget *table, *min_lum, *max_lum, *box, *frame, *label;
+        GtkWidget *table, *box, *frame, *label;
 
         if( (sel_dial = (selection_dialog_t*) 
              malloc( sizeof( selection_dialog_t ) ) ) )
@@ -87,6 +91,10 @@ selection_dialog_t* selection_dialog_new( star_selection_t* selection,
 
                 sel_dial->use_min_lum = gtk_check_button_new_with_label(
                         _("Minimum Luminosity"));
+                gtk_signal_connect( GTK_OBJECT(sel_dial->use_min_lum), 
+                                    "toggled", 
+                                    GTK_SIGNAL_FUNC(cb_lum_button_clicked),
+                                    sel_dial );
                 gtk_table_attach( GTK_TABLE(table), sel_dial->use_min_lum, 
                                   0, 1, 0, 1,
                                   (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 
@@ -95,6 +103,10 @@ selection_dialog_t* selection_dialog_new( star_selection_t* selection,
         
                 sel_dial->use_max_lum = gtk_check_button_new_with_label(
                         _("Maximum Luminosity"));
+                gtk_signal_connect( GTK_OBJECT(sel_dial->use_max_lum), 
+                                    "toggled", 
+                                    GTK_SIGNAL_FUNC(cb_lum_button_clicked),
+                                    sel_dial );
                 gtk_table_attach( GTK_TABLE(table), sel_dial->use_max_lum, 
                                   0, 1, 1, 2,
                                   (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 
@@ -103,20 +115,20 @@ selection_dialog_t* selection_dialog_new( star_selection_t* selection,
         
                 sel_dial->min_lum_adj = gtk_adjustment_new(1, 0, 100, .01, 
                                                            10, 10);
-                min_lum = gtk_spin_button_new( GTK_ADJUSTMENT(sel_dial->
+                sel_dial->min_lum = gtk_spin_button_new( GTK_ADJUSTMENT(sel_dial->
                                                               min_lum_adj), 
                                                0.01, 3);
-                gtk_table_attach( GTK_TABLE(table), min_lum, 1, 2, 0, 1,
+                gtk_table_attach( GTK_TABLE(table), sel_dial->min_lum, 1, 2, 0, 1,
                                   (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 
                                   (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 
                                   0, 0);
         
                 sel_dial->max_lum_adj = gtk_adjustment_new(1, 0, 100, .01, 
                                                            10, 10);
-                max_lum = gtk_spin_button_new( GTK_ADJUSTMENT(sel_dial->
+                sel_dial->max_lum = gtk_spin_button_new( GTK_ADJUSTMENT(sel_dial->
                                                               max_lum_adj), 
                                                0.01, 3);
-                gtk_table_attach( GTK_TABLE(table), max_lum, 1, 2, 1, 2,
+                gtk_table_attach( GTK_TABLE(table), sel_dial->max_lum, 1, 2, 1, 2,
                                   (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 
                                   (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 
                                   0, 0);
@@ -187,6 +199,7 @@ void selection_dialog_show( selection_dialog_t* dialog )
 {
         set_selection( dialog );
         gtk_widget_show( dialog->dialog );
+        gdk_window_raise( dialog->dialog->window );
 }
 
 void selection_dialog_destroy( selection_dialog_t* dialog )
@@ -217,6 +230,20 @@ void cb_clicked(GnomeDialog *d, int but, selection_dialog_t* sel_dial)
         }
 }
 
+void cb_lum_button_clicked( GtkToggleButton *togglebutton,
+                            selection_dialog_t* sel_dial)
+{
+        gtk_widget_set_sensitive(sel_dial->min_lum,
+                                 gtk_toggle_button_get_active( 
+                                         GTK_TOGGLE_BUTTON(sel_dial->
+                                                           use_min_lum) ) );
+        gtk_widget_set_sensitive(sel_dial->max_lum,
+                                 gtk_toggle_button_get_active( 
+                                         GTK_TOGGLE_BUTTON(sel_dial->
+                                                           use_max_lum) ) );
+}
+
+
 static void set_selection( selection_dialog_t* dialog  )
 {
         if( star_selection_is_min_lum( dialog->selection ) )
@@ -302,6 +329,14 @@ static void set_selection( selection_dialog_t* dialog  )
                 gtk_toggle_button_set_active( 
                         GTK_TOGGLE_BUTTON( dialog->show_WD ), TRUE );
         }
+        gtk_widget_set_sensitive(dialog->min_lum,
+                                 gtk_toggle_button_get_active( 
+                                         GTK_TOGGLE_BUTTON(dialog->
+                                                           use_min_lum) ) );
+        gtk_widget_set_sensitive(dialog->max_lum,
+                                 gtk_toggle_button_get_active( 
+                                         GTK_TOGGLE_BUTTON(dialog->
+                                                           use_max_lum) ) );
 }
 
 static void get_selection( selection_dialog_t* dialog )
